@@ -1,6 +1,6 @@
 package Calendar::Bahai;
 
-$Calendar::Bahai::VERSION   = '0.44';
+$Calendar::Bahai::VERSION   = '0.45';
 $Calendar::Bahai::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Calendar::Bahai - Interface to the calendar used by Bahai faith.
 
 =head1 VERSION
 
-Version 0.44
+Version 0.45
 
 =cut
 
@@ -275,29 +275,6 @@ sub as_string {
     return $self->as_text($self->month, $self->year);
 }
 
-#
-#
-# PRIVATE METHODS
-
-sub validate_params {
-    my ($self, $month, $year) = @_;
-
-    if (defined $month && defined $year) {
-        $self->date->validate_month($month);
-        $self->date->validate_year($year);
-
-        if ($month !~ /^\d+$/) {
-            $month = $self->date->get_month_number($month);
-        }
-    }
-    else {
-        $month = $self->month;
-        $year  = $self->year;
-    }
-
-    return ($month, $year);
-}
-
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
